import { request } from 'umi';
import { api } from '../api';

/**
 * 获取组员及组员账号列表
*/
export async function getAdAccountAllOfMember() {
  return request(api + '/adq/adAccount/allOfMember');
}

/**
 * 获取ADQ账号列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 * @param adgroupName 广告名称
 */
export async function getAdqAdAccountList(params: {
  pageNum: number;
  pageSize: number;
  userId?: string;//用户ID
  accountIds?: string[];//账号本地ID
}) {
  return request(api + '/adq/adAccount/list', {
    method: 'POST',
    data: params,
  });
}
/**
 * 按账号同步计划
 * @param adAccountId 本地ID
 */
export async function putAdqAdAccountSyncByIds(data: any) {
  return request(api + `/adq/adAccount/syncByIds`, {
    method: 'PUT',
    data
  });
}
/**
 * 获取ADQ计划列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 * @param adgroupName 广告名称
 */
export async function getAdqCampaignList(params: {
  pageNum: number;
  pageSize: number;
  userId?: string;//用户ID
  accountId?: string;//账号本地ID
  campaignName?: string;//计划名称
  configuredStatus?: string;//计划状态
  campaignType?: string;//计划类型
  promotedObjectType?: string;//推广目标类型
}) {
  return request(api + '/adq/campaign/list', {
    method: 'POST',
    data: params,
  });
}
/**
 * 按账号同步计划
 * @param adAccountId 本地ID
 */
export async function putAdqCampaignPage(adAccountId: any) {
  return request(api + `/adq/campaign/syncAll/${adAccountId} `, {
    method: 'PUT',
  });
}
/**
 * 获取ADQ广告列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 * @param adgroupName 广告名称
 */
export async function getAdqAdgroupsList(params: {
  pageNum: number;
  pageSize: number;
  accountId: string;
  adgroupName?: string
}) {
  return request(api + '/adq/adgroups/list', {
    method: 'POST',
    data: params,
  });
}
/**
 * 同步ADQ广告列表
 *@param adAccountId 本地ID
 */
export async function putAdqAdgroupsSync(data: any) {
  return request(api + `/adq/adgroups/sync`, {
    method: 'PUT',
    data
  });
}

/**
 * 多选删除广告
 * @param data 
 * @returns 
 */
export async function delListAdqAdgroupsApi(data: { adgroupIds: number[] }) {
  return request(api + `/adq/adgroups/delete/batch`, {
    method: 'POST',
    data
  });
}

/**
 * 删除广告
 * @param data 
 * @returns
 */
export async function delAdqAdgroupsApi({ adAccountId, adgroupId }: { adAccountId: number, adgroupId: number }) {
  return request(api + `/adq/adgroups/${adAccountId}/${adgroupId}`, {
    method: 'DELETE'
  });
}

export interface EditAdqAdgroupsProps {
  adgroupIds: number[],   // 广告组id列表
  adgroupsUpdateBidAmountDTO?: { // 出价
    bidAmount: number,  // 出价
    bidMode: string,    // 出价方式
    bidStrategy: string,// 出价策略
    optimizationGoal: string,  // 出价目标
  },
  adgroupsUpdateDatetimeDTO?: { // 排期
    beginDate: string,
    endDate?: string,
    firstDayBeginTime?: string,
    timeSeries?: string
  },
  deepConversionSpec?: { // 深度优化
    deepConversionType: string,
    deepConversionBehaviorSpec?: {
      bidAmount: number,
      goal: string
    },
    deepConversionWorthAdvancedSpec?: {
      expectedRoi: number,
      goal: string
    },
    deepConversionWorthSpec?: {
      expectedRoi: number,
      goal: string
    }
  },
  configuredStatus?: string
}
export async function editAdqAdgroupsDataApi(data: EditAdqAdgroupsProps) {
  return request(api + `/adq/adgroups/update/batch`, {
    method: 'POST',
    data
  });
}
export async function newEditAdqAdgroupsDataApi(data: EditAdqAdgroupsProps) {
  return request(api + `/adq/adgroups/configStatus/update/batch`, {
    method: 'POST',
    data
  });
}
export interface CopyAdProps{
  adgroupIds: number[],   // 广告组id列表
  beginDate: string,
  endDate: string,
  copyCount: number,  // 复制数量
  firstDayBeginTime?: string
  timeSeries?: string
}
export async function copyAdAdApi(data: CopyAdProps) {
  return request(api + `/adq/adgroups/copy/batch`, {
    method: 'POST',
    data
  });
}

/**
 * 获取ADQ创意列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 * @param adcreativeName
 */
export async function getAdqAdcreativeList(params: {
  pageNum: number;
  pageSize: number;
  accountId: string;
  adcreativeName?: string

}) {
  return request(api + '/adq/adcreative/list', {
    method: 'POST',
    data: params,
  });
}

/**
 * 获取ADQ落地页列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 */
export async function getAdqLandingPageList(params: {
  pageNum: number;
  pageSize: number;
  accountId: string;
  pageName: string;
  pageType: string;
  pageTemplateId: string;
  pageStatus: string;
}) {
  return request(api + '/adq/landingPageWechat/list ', {
    method: 'POST',
    data: params,
  });
}

/**
 * 按账号同步落地页
 * @param adAccountId 本地ID
 */
export async function putAdqLandingPage(adAccountId: any) {
  return request(api + `/adq/landingPageWechat/syncAll/${adAccountId} `, {
    method: 'PUT',
  });
}
/**
 * 获取ADQ定向列表
 * @param adgroupName 广告名称
 * @param promotedObjectType 广告类型
 * @param accountId 账户ID
 */
export async function getAdqTargetingList(params: {
  pageNum: number;
  pageSize: number;
  accountId: string;
  pageName: string;
  pageType: string;
  pageTemplateId: string;
  pageStatus: string;
}) {
  return request(api + '/adq/targeting/list ', {
    method: 'POST',
    data: params,
  });
}

/**
 * 按账号同步ADQ定向列表
 * @param adAccountId 本地ID
 */
export async function putAdqTargetingSyncAll(adAccountId: any) {
  return request(api + `/adq/targeting/syncAll/${adAccountId} `, {
    method: 'PUT',
  });
}

/**
 * 计划启停
 * @param adAccountId 本地ID
 */
export async function putAdqCampaignConfigStatus(params: any) {
  let { accountId, campaignId, configuredStatus } = params
  return request(api + `/adq/campaign/configStatus/${accountId}/${campaignId}/${configuredStatus}`, {
    method: 'PUT',
  });
}
/**
 * 广告启停
 * @param adAccountId 本地ID
 */
export async function putAdqAdgroupsConfigStatus(params: any) {
  let { accountId, adgroupId, configuredStatus } = params
  return request(api + `/adq/adgroups/configStatus/${accountId}/${adgroupId}/${configuredStatus}`, {
    method: 'PUT',
  });
}

/**
 * log
 * @param data 
 * @returns 
 */
export async function getLogListApi(data: { accountId?: number, adgroupId?: number, adgroupName?: string, pageNum: number, pageSize: number }) {
  return request(api + `/adq/adgroups/operate/log`, {
    method: 'POST',
    data
  });
}